CssModuleTokenOwnershipCensusV0

Struct CssModuleTokenOwnershipCensusV0 

#[non_exhaustive]
pub struct CssModuleTokenOwnershipCensusV0 {
Show 13 fields pub schema_version: &'static str, pub product: &'static str, pub scope: &'static str, pub emission_path: &'static str, pub complete: bool, pub modeled_preimage_count: usize, pub emitted_token_count: usize, pub token_ownerships: Vec<CssModuleTokenOwnershipV0>, pub module_token_collision_count: usize, pub module_token_collisions: Vec<CssModuleTokenCollisionV0>, pub unattributed_emitted_tokens: Vec<String>, pub interface_mismatches: Vec<CssModuleTokenInterfaceMismatchV0>, pub unavailable_reasons: Vec<String>,
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
schema_version: &'static strproduct: &'static strscope: &'static stremission_path: &'static strcomplete: boolmodeled_preimage_count: usizeemitted_token_count: usizetoken_ownerships: Vec<CssModuleTokenOwnershipV0>module_token_collision_count: usizemodule_token_collisions: Vec<CssModuleTokenCollisionV0>unattributed_emitted_tokens: Vec<String>interface_mismatches: Vec<CssModuleTokenInterfaceMismatchV0>unavailable_reasons: Vec<String>

Implementations

Source

impl CssModuleTokenOwnershipCensusV0

pub fn new( emission_path: &'static str, modeled_preimage_count: usize, token_ownerships: Vec<CssModuleTokenOwnershipV0>, module_token_collisions: Vec<CssModuleTokenCollisionV0>, unattributed_emitted_tokens: Vec<String>, interface_mismatches: Vec<CssModuleTokenInterfaceMismatchV0>, ) -> Self

pub fn unavailable( emission_path: &'static str, reason: impl Into<String>, ) -> Self

Source

impl CssModuleTokenOwnershipCensusV0

pub fn execute_module_transform_passes_with_ownership_admission( &self, source: &str, dialect: StyleDialect, requested: &[TransformPassKind], context: &TransformExecutionContextV0, closed_world_bundle: &ClosedWorldBundleV0, module_instance: &ModuleInstanceKeyV0, reachability_precision: FactPrecision, execution_policy: &TransformExecutionPolicyV0, retained_class_names: &[String], ) -> Result<TransformExecutionSummaryV0, TransformModuleQualifiedExecutionErrorV0>

Executes one module while using this product census as ownership admission authority.

pub fn execute_module_transform_passes_with_ownership_admission_for_identity( &self, source: &str, dialect: StyleDialect, requested: &[TransformPassKind], context: &TransformExecutionContextV0, closed_world_bundle: &ClosedWorldBundleV0, module_instance: &ModuleInstanceKeyV0, ownership_module_instance: &ModuleInstanceKeyV0, reachability_precision: FactPrecision, execution_policy: &TransformExecutionPolicyV0, retained_class_names: &[String], ) -> Result<TransformExecutionSummaryV0, TransformModuleQualifiedExecutionErrorV0>

Executes one module while comparing ownership evidence in its census identity space.

module_instance remains the sealed-bundle lookup and diagnostic identity. The separate ownership_module_instance is the identity used by the census producer, which can be workspace-root relative even when bundle keys are absolute.