#[non_exhaustive]pub struct TransformPlanDependencyCycleV0 {
pub cycle_path: Vec<&'static str>,
pub dependency_edges: Vec<TransformPlanDependencyEdgeV0>,
}Expand description
A closed dependency path that prevents the planner from selecting a next pass.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cycle_path: Vec<&'static str>Pass identifiers in traversal order, with the first identifier repeated at the end.
dependency_edges: Vec<TransformPlanDependencyEdgeV0>Trait Implementations
Sourceimpl Clone for TransformPlanDependencyCycleV0
impl Clone for TransformPlanDependencyCycleV0
Sourcefn clone(&self) -> TransformPlanDependencyCycleV0
fn clone(&self) -> TransformPlanDependencyCycleV0
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for TransformPlanDependencyCycleV0
impl StructuralPartialEq for TransformPlanDependencyCycleV0